@@ -1,17 +1,27 @@
-from popsynth.population_synth import PopulationSynth
-from popsynth.populations import *
-from popsynth.aux_samplers import *
-
-from popsynth.population import Population
-from popsynth.auxiliary_sampler import AuxiliarySampler, DerivedLumAuxSampler, NonObservedAuxSampler, AuxiliaryParameter
-from popsynth.distribution import DistributionParameter, LuminosityDistribution, SpatialDistribution
-
-
-import popsynth.populations as populations
-
-
 import scipy.stats as stats
 
+import popsynth.populations as populations
+from popsynth.aux_samplers import *
+from popsynth.auxiliary_sampler import (
+    AuxiliaryParameter,
+    AuxiliarySampler,
+    DerivedLumAuxSampler,
+    NonObservedAuxSampler,
+)
+from popsynth.distribution import (
+    DistributionParameter,
+    LuminosityDistribution,
+    SpatialDistribution,
+)
+from popsynth.population import Population
+from popsynth.population_synth import PopulationSynth
+from popsynth.populations import *
+from popsynth.selection_probability import (
+    BernoulliSelection,
+    HardFluxSelection,
+    SoftFluxSelection,
+    UnitySelection,
+)
 
 __all__ = [
     "AuxiliarySampler",
